# Prefecto

<p align="center">
    <img src="https://raw.githubusercontent.com/dominictarro/prefecto/main/docs/assets/Monkeywrench-Data-Pipeline.png">
    <br>
    <a href="https://pypi.python.org/pypi/prefecto/" alt="PyPI version">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/prefecto?color=fe7200&labelColor=eeeeee"></a>
    <a href="https://github.com/dominictarro/prefecto/" alt="Stars">
        <img src="https://img.shields.io/github/stars/dominictarro/prefecto?color=fe7200&labelColor=eeeeee" /></a>
    <a href="https://github.com/dominictarro/prefecto/pulse" alt="Activity">
        <img src="https://img.shields.io/github/commit-activity/m/dominictarro/prefecto?color=fe7200&labelColor=eeeeee" /></a>
</p>

Prefecto is a collection of tools to extend and augment [Prefect](https://www.prefect.io/) capabilities.

You can find the documentation [here](https://dominictarro.github.io/prefecto/).

## Getting Started

Install Prefecto with

```bash
pip install prefecto
```

*Prefecto is only tested with Python 3.10 and higher. It may work with older versions, but it is not guaranteed.*
